local addonName, addon = ...
local Buzzbox = addon

addon.Options = {
  type = "group",
  name = "Buzzbox v"..addon.version.."",

  childGroups = "tree",
  handler = Buzzbox,

  args = {

    usage_commands = {

      type = "group",
      name = "Device",
      desc = "Type /bb <command> to quickly do the following operations:",
      inline = true,
      order = 0,
      args = {

        mic = {
          order = 2,
          name = "Mic",
          width = "half",
          desc = "Mutes / Unmutes the microphone",
          type = "execute",
          func = "ToggleMic"
        },

        io = {
          order = 1,
          name = "I/O",
          width = "half",
          desc = "Turns the Buzzbox on and off",
          type = "execute",
          func = "ToggleStatus"
        },

        freq = {
          order = 3,
          name = "Tuning Frequency",
          desc = "Sets the frequency your Buzzbox is tuned to",
          type = "range",
          min = 100,
          max = 999,
          step = 1,
          set = function(info,val) Buzzbox.db.profile.tfreq = val end,
          get = function(info) return Buzzbox.db.profile.tfreq end
        },

        vol = {
          order = 4,
          name = "Volume",
          desc = "You can mute your Buzzbox, set it so you have to hold it up to your ear to hear it, or have it broadcast everything while it's hooked on your belt!",
          type = "range",
          min = 0,
          max = 1,
          step = 0.5,
          set = function(info,val) Buzzbox.db.profile.volume = val end,
          get = function(info) return Buzzbox.db.profile.volume end
        },
      }
    },

    preferences = {

      type = "group",
      name = "Preferences",
      cmdHidden = true,
      order = 1,
      args = {

        sender_name = {
          name = "Sender's name display style",
          desc = "Select the way you want the sender's name to be displayed",
          type = "select",
          style = "dropdown",
          order = 6,
          values = {"(( Sent by ... ))","Part of the emote","Do not show sender's name"},
          set = function(info, val) Buzzbox.db.profile.sendernameopt = val; end,
          get = function(info) return Buzzbox.db.profile.sendernameopt end
        },

        sendernameopt = {
          type = "toggle",
          name = "Show IC names",
          desc = "Toggle between showing IC names or actual, OOC, character names",
          width = "full",
          order = 2,
          set = function(info, val) Buzzbox.db.profile.senderRPnameopt = val; end,
          get = function(info) return Buzzbox.db.profile.senderRPnameopt end
        },

        message_noise = {
          type = "toggle",
          name = "Low signal crackles",
          desc = "Enable / Disable crackles in low signal messages",
          width = "full",
          order = 1,
          set = function(info, val) Buzzbox.db.profile.noiseopt = val; end,
          get = function(info) return Buzzbox.db.profile.noiseopt end
        },

        encryption = {
          type = "toggle",
          name = "Encryption",
          desc = "Enable end-to-end encryption",
          order = 4,
          set = function(info, val) Buzzbox.db.profile.encryptionopt = val; end,
          get = function(info) return Buzzbox.db.profile.encryptionopt end
        },

        minimap_button = {
          type = "toggle",
          name = "Hide minimap button",
          desc = "Hide the minimap button",
          width = "full",
          order = 3,
          set = function(info, val) Buzzbox:ToggleMinimapButton(); end,
          get = function(info) return Buzzbox.db.profile.minimap.hide end
        },

        encryption_key = {
          type = "input",
          name = "Encryption Key",
          desc = "Enter a key to encrypt and decrypt messages",
          order = 5,
          set = function(info, val) Buzzbox.db.profile.encryptionKey = val:gsub("%s+",""); end,
          get = function(info) return Buzzbox.db.profile.encryptionKey end,
          validate =
          function(info, val)
            if string.len(val)>8 then
              Buzzbox:Print("Your key cannot be more than eight characters.")
              return "Error"
            elseif val=="" then
              Buzzbox.db.profile.encryptionKey = "0"
              return "Error"
            else
              return true
            end
          end
        }
      }
    },

    about = {
      type = "group",
      name = "About",
      cmdHidden = true,
      order = -1,
      args = {
        Msg = {
          name = "Written by peinzser. To report issues visit the project page \nhttps://www.wowace.com/projects/buzzbox",
          type = "description",
          fontSize = "medium",
          order = 1
        }
      }
    }
  }

}
